@@ -38,6 +38,7 @@ decrypt<-function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)
 #' @param data A dataset
 #' @param target Target variable (0/1, TRUE/FALSE, yes/no)
 #' @param min_prop Minimum proportion of one of the target categories
+#' @param seed Seed for random number generator
 #' @return Data
 #' @import rlang
 #' @import dplyr
@@ -47,7 +48,7 @@ decrypt<-function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)
 #' describe(balanced, is_versicolor)
 #' @export
 
-balance_target <- function(data, target, min_prop = 0.1) {
+balance_target <- function(data, target, min_prop = 0.1, seed) {
 
   # check if parameters are missing
   if (missing(data))  {
@@ -85,15 +86,27 @@ balance_target <- function(data, target, min_prop = 0.1) {
     return(data)
 
   } else {
-    data_minClass <- data %>%
-      dplyr::filter(!!target_quo == names(minClass)) %>%
+
+    tmp_min <- data %>% dplyr::filter(!!target_quo == names(minClass))
+    tmp_max <- data %>% dplyr::filter(!!target_quo != names(minClass))
+
+    # set seed (if defined) to ensure reproducibility
+    if (!missing(seed)) {set.seed(seed)}
+
+    # sampling
+    data_minClass <- tmp_min %>%
       dplyr::sample_n(minClass)
-    data_maxClass <- data %>%
-      dplyr::filter(!!target_quo != names(minClass)) %>%
+    data_maxClass <- tmp_max %>%
       dplyr::sample_n(maxClass)
 
-    return(rbind(data_minClass, data_maxClass))
-  }
+    # mix it up
+    data <- rbind(data_minClass, data_maxClass)
+    if (!missing(seed)) {set.seed(seed)}
+    data <- data %>% dplyr::sample_n(nrow(data))
+
+    # return
+    data
+    }
 } # balance_target
 
 #' Weight target variable
@@ -402,7 +415,7 @@ format_type <- function(type) {
 
 #' Return type of variable
 #'
-#' Return value of typeof, except if variable contains <hide>, then return "other"
+#' Return value of typeof, except if variable contains hide, then return "other"
 #'
 #' @param var A vector (dataframe column)
 #' @return Value of typeof or "other"
@@ -865,255 +878,3 @@ count_pct <- function(data, ...)  {
 
   d
 } # count_pct
-
-
-#' Add a random variable to dataset
-#'
-#' @param data A dataset
-#' @param name Name of new variable (as string)
-#' @param min_val Minimum random integers
-#' @param max_val Maximum random integers
-#' @param overwrite Can new random variable overwrite an existing variable in dataset?
-#' @return Dataset containing new random variable
-#' @examples
-#' add_random_var(iris)
-#' add_random_var(iris, name = "random_var")
-#' add_random_var(iris, min_val = 1, max_val = 10)
-#' add_random_var(iris, min_val = 1, max_val = 100, overwrite = FALSE)
-#' @export
-
-add_random_var <- function(data, name = "random",
-                           min_val = 0, max_val = 1,
-                           overwrite = TRUE) {
-
-  if (name %in% names(data) & !overwrite) {
-    stop("Variable ", name, " already exists!")
-  }
-
-  # possible integer values
-  values <- seq(from = min_val, to = max_val)
-
-  # add random variable
-  data[[name]] <- sample(values, nrow(data), replace = TRUE)
-
-  # return data
-  data
-
-} #add_random_var
-
-
-#' Create fake data
-#'
-#' Fake data that can be used for unit-testing or demonstration
-#'
-#' @param obs Number of observations
-#' @param target_name Variable name of target
-#' @param factorise_target Should target variable be factorised?
-#' (from 0/1 to facotr no/yes)?
-#' @param target1_prob Probability that buy = 1
-#' @param add_extreme Add an obervation with extreme values?
-#' @param flip_gender Should Male/Female be flipped in data?
-#' @param add_id Add an id-variable to data?
-#' @param seed Seed for randomization
-#'
-#' @return A dataframe
-#' @export
-#'
-#' @md
-#' @details
-#' Variables in dataset:
-#' * id = Identifier
-#' * period = Year & Month (YYYYMM)
-#' * city_ind = Indicating if customer is residing in a city (1 = yes, 0 = no)
-#' * female_ind = Gender of customer is female (1 = yes, 0 = no)
-#' * fixedvoice_ind = Customer has a fixed voice product (1 = yes, 0 = no)
-#' * fixeddata_ind = Customer has a fixed data product (1 = yes, 0 = no)
-#' * fixedtv_ind = Customer has a fixed tv product (1 = yes, 0 = no)
-#' * mobilevoice_ind = Customer has a mobile voice product (1 = yes, 0 = no)
-#' * mobiledata_ind = Customer has a mobile data product (1 = yes, 0 = no)
-#' * bbi_speed_ind = Customer has a Broadband Internet (BBI) with speed
-#' * bbi_usg_gb = Broadband Internet (BBI) usage in Gigabyte (GB) last month
-#' * hh_single = Expected to be a Single Household (1 = yes, 0 = no)
-#'
-#' Target in dataset:
-#' * target_ind (may be renamed) = Did customer buy a new product in next month?
-#' (1 = yes, 0 = no)
-
-
-create_fake_data = function(obs = 1000,
-                            target_name = "target_ind",
-                            factorise_target = FALSE,
-                            target1_prob = 0.5,
-                            add_extreme = TRUE,
-                            flip_gender = FALSE,
-                            add_id = FALSE,
-                            seed = 123) {
-
-  # define variables for CRAN-package check
-  target_ind <- NULL
-  age <- NULL
-  city_ind <- NULL
-
-  # set seed (randomization)
-  set.seed(seed)
-
-  # create basic dataset
-  data <- data.frame(
-    id = seq(from = 1, to = obs),
-    period = rep(202012, obs),
-    target_ind = sample(c(0, 1),
-                        obs,
-                        prob = c(1 - target1_prob, target1_prob),
-                        replace = TRUE)
-  )
-
-  # add features
-  data <- data %>%
-    dplyr::mutate(
-      age = round(ifelse(target_ind == 1,
-                         stats::rnorm(obs, mean = 45, sd = 10),
-                         stats::rnorm(obs, mean = 60, sd = 10)
-      ), 0),
-      city_ind = ifelse(target_ind == 1,
-                        sample(c(0, 1), obs, replace = TRUE, prob = c(0.4, 0.6)),
-                        sample(c(0, 1), obs, replace = TRUE, prob = c(0.6, 0.4))
-      ),
-      female_ind = ifelse(target_ind == 1,
-                          sample(c(0, 1), obs, replace = TRUE, prob = c(0.3, 0.7)),
-                          sample(c(0, 1), obs, replace = TRUE, prob = c(0.7, 0.3))
-      ),
-      fixedvoice_ind = ifelse(age > 70,
-                              sample(c(0, 1), obs, replace = TRUE, prob = c(0.3, 0.7)),
-                              sample(c(0, 1), obs, replace = TRUE, prob = c(0.95, 0.05))
-      ),
-      fixeddata_ind = 1,
-      fixedtv_ind = ifelse(target_ind == 1,
-                           sample(c(0, 1), obs, replace = TRUE, prob = c(0.4, 0.6)),
-                           sample(c(0, 1), obs, replace = TRUE, prob = c(0.8, 0.2))
-      ),
-      mobilevoice_ind = sample(c(0, 1), obs, replace = TRUE, prob = c(0.4, 0.6)),
-      mobiledata_ind = sample(c("NO","MOBILE STICK", "BUSINESS"), obs, replace = TRUE, prob = c(0.5, 0.3, 0.2)),
-      bbi_speed_ind = ifelse(age > 60,
-                             sample(c(0, 1), obs, replace = TRUE, prob = c(0.9, 0.1)),
-                             sample(c(0, 1), obs, replace = TRUE, prob = c(0.2, 0.8))
-      ),
-      bbi_usg_gb = ifelse(age > 75,
-                          round(stats::rnorm(obs, mean = 10, sd = 1)),
-                          round(stats::rnorm(obs, mean = 50, sd = 10))
-      ) + city_ind * 20 + target_ind * 10,
-      hh_single = ifelse(age < 35 & city_ind == 1,
-                         sample(c(0, 1), obs, replace = TRUE, prob = c(0.2, 0.8)),
-                         sample(c(0, 1), obs, replace = TRUE, prob = c(0.7, 0.3))
-      )
-    ) # mutate
-
-  # factorise target?
-  if (factorise_target) {
-    data$buy <- factor(data$buy,
-                       levels = c(0, 1),
-                       labels = c("no", "yes"))
-  }
-
-  # add extreme values?
-  if (add_extreme) {
-    extreme <- data[nrow(data), ]
-    extreme$bbi_usg_gb <- 100000
-    extreme$target_ind <- 0
-    data[nrow(data), ] <- extreme[1, ]
-  }
-
-  # rename target?
-  if (target_name != "target_ind") {
-    data[[target_name]] <- data$target_ind
-    data$target_ind <- NULL
-  }
-
-  # flip gender?
-  if (flip_gender) {
-    data[["female_ind"]] <- ifelse(data[["female_ind"]] == 1, 0, 1)
-  }
-
-  # add id?
-  if (!add_id)  {
-    data$id <- NULL
-  }
-
-  # return data
-  data
-
-} # fakedata
-
-#' Create random data
-#'
-#' Random data that can be used for unit-testing or demonstration
-#'
-#' @param obs Number of observations
-#' @param vars Number of variables
-#' @param target_name Variable name of target
-#' @param factorise_target Should target variable be factorised?
-#' (from 0/1 to facotr no/yes)?
-#' @param target1_prob Probability that buy = 1
-#' @param add_id Add an id-variable to data?
-#' @param seed Seed for randomization
-#'
-#' @return A dataframe
-#' @export
-#'
-#' @md
-#' @details
-#' Variables in dataset:
-#' * id = Identifier
-#' * var_X = variable containing values between 0 and 100
-#'
-#' Target in dataset:
-#' * target_ind (may be renamed) = random values (1 = yes, 0 = no)
-
-
-create_random_data = function(obs = 1000, vars = 10,
-                              target_name = "target_ind",
-                              factorise_target = FALSE,
-                              target1_prob = 0.5,
-                              add_id = TRUE,
-                              seed = 123) {
-
-  # set seed (randomization)
-  set.seed(seed)
-
-  # create basic dataset
-  data <- data.frame(
-    id = seq(from = 1, to = obs),
-    target_ind = sample(c(0, 1),
-                        obs,
-                        prob = c(1 - target1_prob, target1_prob),
-                        replace = TRUE)
-  )
-
-  # add features
-  for (i in seq_len(vars)) {
-    data[[paste0("var_",i)]] <- as.integer(
-      round(stats::runif(obs)*100,0))
-  }
-
-
-  # factorise target?
-  if (factorise_target) {
-    data$buy <- factor(data$buy,
-                       levels = c(0, 1),
-                       labels = c("no", "yes"))
-  }
-
-  # rename target?
-  if (target_name != "target_ind") {
-    data[[target_name]] <- data$target_ind
-    data$target_ind <- NULL
-  }
-
-  # add id?
-  if (!add_id)  {
-    data$id <- NULL
-  }
-
-  # return data
-  data
-
-} # randomdata
